import { M as MastraBase } from '../base-H7siSAfu.cjs';
import { VectorFilter } from './filter/index.cjs';
import '@opentelemetry/api';
import '../index-QV27jkxQ.cjs';
import 'stream';
import 'pino';
import '@opentelemetry/sdk-trace-base';

interface QueryResult {
    id: string;
    score: number;
    metadata?: Record<string, any>;
    vector?: number[];
    /**
     * The document content, if available.
     * Note: Currently only supported by Chroma vector store.
     * For other vector stores, documents should be stored in metadata.
     */
    document?: string;
}
interface IndexStats {
    dimension: number;
    count: number;
    metric?: 'cosine' | 'euclidean' | 'dotproduct';
}
interface UpsertVectorParams {
    indexName: string;
    vectors: number[][];
    metadata?: Record<string, any>[];
    ids?: string[];
}
type UpsertVectorArgs = [string, number[][], Record<string, any>[], string[]?];
interface CreateIndexParams {
    indexName: string;
    dimension: number;
    metric?: 'cosine' | 'euclidean' | 'dotproduct';
}
type CreateIndexArgs = [string, number, 'cosine' | 'euclidean' | 'dotproduct'];
interface QueryVectorParams {
    indexName: string;
    queryVector: number[];
    topK?: number;
    filter?: VectorFilter;
    includeVector?: boolean;
}
type QueryVectorArgs = [string, number[], number, VectorFilter?, boolean?];
interface DescribeIndexParams {
    indexName: string;
}
type DescribeIndexArgs = [string];
interface DeleteIndexParams {
    indexName: string;
}
type DeleteIndexArgs = [string];
interface UpdateVectorParams {
    indexName: string;
    id: string;
    update: {
        vector?: number[];
        metadata?: Record<string, any>;
    };
}
type UpdateVectorArgs = [string, string, {
    vector?: number[];
    metadata?: Record<string, any>;
}];
interface DeleteVectorParams {
    indexName: string;
    id: string;
}
type DeleteVectorArgs = [string, string];
type ParamsToArgs<T> = [T] | (T extends QueryVectorParams ? QueryVectorArgs : never) | (T extends UpsertVectorParams ? UpsertVectorArgs : never) | (T extends CreateIndexParams ? CreateIndexArgs : never) | (T extends DescribeIndexParams ? DescribeIndexArgs : never) | (T extends DeleteIndexParams ? DeleteIndexArgs : never) | (T extends UpdateVectorParams ? UpdateVectorArgs : never) | (T extends DeleteVectorParams ? DeleteVectorArgs : never);

declare abstract class MastraVector extends MastraBase {
    constructor();
    get indexSeparator(): string;
    private readonly baseKeys;
    protected normalizeArgs<T, E extends any[] = never>(method: string, [first, ...rest]: ParamsToArgs<T> | E, extendedKeys?: string[]): T;
    abstract query<E extends QueryVectorArgs = QueryVectorArgs>(...args: ParamsToArgs<QueryVectorParams> | E): Promise<QueryResult[]>;
    abstract upsert<E extends UpsertVectorArgs = UpsertVectorArgs>(...args: ParamsToArgs<UpsertVectorParams> | E): Promise<string[]>;
    abstract createIndex<E extends CreateIndexArgs = CreateIndexArgs>(...args: ParamsToArgs<CreateIndexParams> | E): Promise<void>;
    abstract listIndexes(): Promise<string[]>;
    abstract describeIndex(...args: ParamsToArgs<DescribeIndexParams>): Promise<IndexStats>;
    abstract deleteIndex(...args: ParamsToArgs<DeleteIndexParams>): Promise<void>;
    abstract updateVector(...args: ParamsToArgs<UpdateVectorParams>): Promise<void>;
    abstract deleteVector(...args: ParamsToArgs<DeleteVectorParams>): Promise<void>;
    protected validateExistingIndex(indexName: string, dimension: number, metric: string): Promise<void>;
}

export { type CreateIndexArgs, type CreateIndexParams, type DeleteIndexArgs, type DeleteIndexParams, type DeleteVectorArgs, type DeleteVectorParams, type DescribeIndexArgs, type DescribeIndexParams, type IndexStats, MastraVector, type ParamsToArgs, type QueryResult, type QueryVectorArgs, type QueryVectorParams, type UpdateVectorArgs, type UpdateVectorParams, type UpsertVectorArgs, type UpsertVectorParams };
